==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/FinancialChartDropDownControl.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { TemplatedHtmlControl } from "./TemplatedHtmlControl";
import { EventArgs, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var FinancialChartDropDownControl = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialChartDropDownControl, _super);
    function FinancialChartDropDownControl(a, b, c) {
        var _this = _super.call(this, a, b, c) || this;
        _this.selectionChanged = null;
        _this.o = null;
        _this.p = null;
        return _this;
    }
    FinancialChartDropDownControl.prototype.v = function () {
        if (this.selectionChanged != null) {
            this.selectionChanged(this, EventArgs.empty);
        }
    };
    FinancialChartDropDownControl.prototype.l = function (a) {
        _super.prototype.l.call(this, a);
        this.o.f(this.d, this.p, this.s, this.t);
    };
    FinancialChartDropDownControl.prototype.get_q = function () {
        return false;
    };
    Object.defineProperty(FinancialChartDropDownControl.prototype, "q", {
        get: function () {
            return this.get_q();
        },
        enumerable: false,
        configurable: true
    });
    FinancialChartDropDownControl.prototype.u = function (a) {
        if (this.p.isOpen) {
            var b = a.target;
            var c = b.matches(this.s + " *");
            var d = c || (this.q && b.matches(this.t + " *"));
            if (!d) {
                this.p.isOpen = false;
                this.p.updateUI();
            }
        }
    };
    FinancialChartDropDownControl.$t = markType(FinancialChartDropDownControl, 'FinancialChartDropDownControl', TemplatedHtmlControl.$);
    return FinancialChartDropDownControl;
}(TemplatedHtmlControl));
export { FinancialChartDropDownControl };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/FinancialChartDropDownControl.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { TemplatedHtmlControl } from "./TemplatedHtmlControl";
import { EventArgs, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var FinancialChartDropDownControl = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialChartDropDownControl, _super);
    function FinancialChartDropDownControl(a, b, c) {
        var _this = _super.call(this, a, b, c) || this;
        _this.selectionChanged = null;
        _this.o = null;
        _this.p = null;
        return _this;
    }
    FinancialChartDropDownControl.prototype.v = function () {
        if (this.selectionChanged != null) {
            this.selectionChanged(this, EventArgs.empty);
        }
    };
    FinancialChartDropDownControl.prototype.l = function (a) {
        _super.prototype.l.call(this, a);
        this.o.f(this.d, this.p, this.s, this.t);
    };
    FinancialChartDropDownControl.prototype.get_q = function () {
        return false;
    };
    Object.defineProperty(FinancialChartDropDownControl.prototype, "q", {
        get: function () {
            return this.get_q();
        },
        enumerable: false,
        configurable: true
    });
    FinancialChartDropDownControl.prototype.u = function (a) {
        if (this.p.isOpen) {
            var b = a.target;
            var e_ = a;
            if ((e_.composed)) {
                var c = (e_.composedPath());
                if (c != null && c.length > 0) {
                    b = c[0];
                }
            }
            var d = b.matches(this.s + " *");
            var e = d || (this.q && b.matches(this.t + " *"));
            if (!e) {
                this.p.isOpen = false;
                this.p.updateUI();
            }
        }
    };
    FinancialChartDropDownControl.$t = markType(FinancialChartDropDownControl, 'FinancialChartDropDownControl', TemplatedHtmlControl.$);
    return FinancialChartDropDownControl;
}(TemplatedHtmlControl));
export { FinancialChartDropDownControl };
